@@ -24,9 +24,12 @@ from timeside.analyzer.core import Analyzer
 from timeside.analyzer.utils import melFilterBank, computeModulation
 from timeside.analyzer.utils import segmentFromValues
 from timeside.api import IAnalyzer
-from numpy import array, hamming, dot, mean, float
+import numpy as np
 from numpy.fft import rfft
 from scipy.signal import firwin, lfilter
+from timeside.analyzer.preprocessors import frames_adapter
+
+from timeside.tools.parameters import Float, HasTraits
 
 
 class IRITSpeech4Hz(Analyzer):
@@ -48,12 +51,15 @@ class IRITSpeech4Hz(Analyzer):
 
     implements(IAnalyzer)
 
+    # Define Parameters
+    class _Param(HasTraits):
+        medfilt_duration = Float()
+
     @interfacedoc
-    def setup(self, channels=None, samplerate=None, blocksize=None,
-              totalframes=None):
-        super(IRITSpeech4Hz, self).setup(
-            channels, samplerate, blocksize, totalframes)
+    def __init__(self, medfilt_duration=5):
+        super(IRITSpeech4Hz, self).__init__()
         self.energy4hz = []
+
         # Classification
         self.threshold = 2.0
 
@@ -63,11 +69,25 @@ class IRITSpeech4Hz(Analyzer):
         self.orderFilter = 100
 
         self.normalizeEnergy = True
+        self.modulLen = 2.0
+
+        # Median filter duration in second
+        self.medfilt_duration = medfilt_duration
+
+    @interfacedoc
+    def setup(self, channels=None, samplerate=None, blocksize=None,
+              totalframes=None):
+        super(IRITSpeech4Hz, self).setup(
+            channels, samplerate, blocksize, totalframes)
         self.nFFT = 2048
         self.nbFilters = 30
-        self.modulLen = 2.0
         self.melFilter = melFilterBank(self.nbFilters, self.nFFT, samplerate)
 
+        self.wLen = 0.016
+        self.wStep = 0.008
+        self.input_blocksize = int(self.wLen * samplerate)
+        self.input_stepsize = int(self.wStep * samplerate)
+
     @staticmethod
     @interfacedoc
     def id():
@@ -86,6 +106,7 @@ class IRITSpeech4Hz(Analyzer):
     def __str__(self):
         return "Speech confidences indexes"
 
+    @frames_adapter
     def process(self, frames, eod=False):
         '''
 
@@ -93,11 +114,11 @@ class IRITSpeech4Hz(Analyzer):
 
         frames = frames.T[0]
         # windowing of the frame (could be a changeable property)
-        w = frames * hamming(len(frames))
+        w = frames * np.hamming(len(frames))
 
         # Mel scale spectrum extraction
         f = abs(rfft(w, n=2 * self.nFFT)[0:self.nFFT])
-        e = dot(f ** 2, self.melFilter)
+        e = np.dot(f ** 2, self.melFilter)
 
         self.energy4hz.append(e)
 
@@ -114,13 +135,13 @@ class IRITSpeech4Hz(Analyzer):
         num = firwin(self.orderFilter, Wn, pass_zero=False)
 
         # Energy on the frequency range
-        self.energy4hz = array(self.energy4hz)
+        self.energy4hz = np.array(self.energy4hz)
         energy = lfilter(num, 1, self.energy4hz.T, 0)
         energy = sum(energy)
 
         # Normalization
         if self.normalizeEnergy and energy.any():
-            energy = energy / mean(energy)
+            energy = energy / np.mean(energy)
 
         # Energy Modulation
         frameLenModulation = int(
@@ -128,7 +149,7 @@ class IRITSpeech4Hz(Analyzer):
         modEnergyValue = computeModulation(energy, frameLenModulation, True)
 
         # Confidence Index
-        conf = array(modEnergyValue - self.threshold) / self.threshold
+        conf = np.array(modEnergyValue - self.threshold) / self.threshold
         conf[conf > 1] = 1
 
         modEnergy = self.new_result(data_mode='value', time_mode='framewise')
@@ -137,31 +158,55 @@ class IRITSpeech4Hz(Analyzer):
 
         modEnergy.data_object.value = conf
 
-        self.process_pipe.results.add(modEnergy)
+        self.add_result(modEnergy)
 
         # Segment
         convert = {False: 0, True: 1}
         label = {0: 'nonSpeech', 1: 'Speech'}
 
-        segList = segmentFromValues(modEnergyValue > self.threshold)
-        # Hint : Median filtering could imrove smoothness of the result
-        # from scipy.signal import medfilt
-        # segList = segmentFromValues(medfilt(modEnergyValue > self.threshold, 31))
+        decision = modEnergyValue > self.threshold
+
+        segList = segmentFromValues(decision)
+        # Hint : Median filtering could improve smoothness of the result
+        from scipy.signal import medfilt
+        output_samplerate = np.float(self.samplerate()) / self.input_stepsize
+        N = int(np.ceil(self.medfilt_duration * output_samplerate))
+        N += 1 - np.mod(N, 2)  # Make N odd
+        segList_filt = segmentFromValues(medfilt(decision, N))
 
         segs = self.new_result(data_mode='label', time_mode='segment')
         segs.id_metadata.id += '.' + 'segments'
         segs.id_metadata.name += ' ' + 'Segments'
 
-        segs.label_metadata.label = label
+        segs.data_object.label_metadata.label = label
 
         segs.data_object.label = [convert[s[2]] for s in segList]
-        segs.data_object.time = [(float(s[0]) * self.blocksize() /
+        segs.data_object.time = [(np.float(s[0]) * self.blocksize() /
                                  self.samplerate())
                                  for s in segList]
-        segs.data_object.duration = [(float(s[1] - s[0] + 1) * self.blocksize() /
+        segs.data_object.duration = [(np.float(s[1] - s[0] + 1) * self.blocksize() /
                                      self.samplerate())
                                      for s in segList]
 
-        self.process_pipe.results.add(segs)
+        self.add_result(segs)
+
+        # Median filter on decision
+        segs = self.new_result(data_mode='label', time_mode='segment')
+        segs.id_metadata.id += '.' + 'segments_median'
+        segs.id_metadata.name += ' ' + 'Segments after Median filtering'
+
+        segs.data_object.label_metadata.label = label
+
+        segs.data_object.label = [convert[s[2]] for s in segList_filt]
+        segs.data_object.time = [(np.float(s[0]) * self.blocksize() /
+                                 self.samplerate())
+                                 for s in segList_filt]
+        segs.data_object.duration = [(np.float(s[1] - s[0] + 1) * self.blocksize() /
+                                     self.samplerate())
+                                     for s in segList_filt]
+
+        self.add_result(segs)
+
+
 
         return
