@@ -30,25 +30,17 @@ from __future__ import division
 
 from timeside.core import Processor, implements, interfacedoc, abstract
 from timeside.api import IDecoder
-from timeside.tools import *
-
-from utils import get_uri, get_media_uri_info, stack
-
-import Queue
-from gst import _gst as gst
-import numpy as np
-
-
-GST_APPSINK_MAX_BUFFERS = 10
-QUEUE_SIZE = 10
 
 
 class Decoder(Processor):
+
     """General abstract base class for Decoder
     """
     implements(IDecoder)
     abstract()
 
+    type = 'decoder'
+
     mimetype = ''
     output_samplerate = None
     output_channels = None
@@ -93,7 +85,12 @@ class Decoder(Processor):
                     duration=self.uri_duration,
                     start=self.uri_start,
                     is_segment=self.is_segment,
-                    samplerate=self.input_samplerate)
+                    samplerate=self.input_samplerate,
+                    sha1=self.sha1)
+
+    @property
+    def sha1(self):
+        return self._sha1
 
     def __del__(self):
         self.release()
@@ -105,7 +102,3 @@ class Decoder(Processor):
     @interfacedoc
     def resolution(self):
         return self.input_width
-
-    def stop(self):
-        self.src.send_event(gst.event_new_eos())
-
